package com.link.core.util.redisclient;

import com.link.core.util.CoreYmlConstants;
import java.util.HashSet;
import java.util.Set;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import redis.clients.jedis.HostAndPort;
import redis.clients.jedis.JedisCluster;
import redis.clients.jedis.JedisPoolConfig;

public class JedisClusterSingleton {
   private static final Logger logger = LogManager.getLogger(JedisClusterSingleton.class);
   private static volatile JedisClusterSingleton instance;
   private JedisCluster jedisCluster;

   public static JedisClusterSingleton getInstance() {
      if (null == instance) {
         Class var0 = JedisClusterSingleton.class;
         synchronized(JedisClusterSingleton.class) {
            if (null == instance) {
               instance = new JedisClusterSingleton();
            }
         }
      }

      return instance;
   }

   public JedisClusterSingleton() {
      JedisPoolConfig poolConfig = new JedisPoolConfig();
      poolConfig.setMaxIdle(500);
      poolConfig.setMaxTotal(3000);
      poolConfig.setMinIdle(50);
      String redisClusterNodes = CoreYmlConstants.getRedisClusterNodes();
      Integer redisClusterCommandTimeout = CoreYmlConstants.getRedisClusterCommandTimeout();
      String redisClusterPassword = CoreYmlConstants.getRedisClusterPassword();
      logger.error("获取到的redis#cluster节点：" + redisClusterNodes);
      String[] serverArray = redisClusterNodes.split(",");
      Set<HostAndPort> nodes = new HashSet();
      String[] var7 = serverArray;
      int var8 = serverArray.length;

      for(int var9 = 0; var9 < var8; ++var9) {
         String ipPort = var7[var9];
         String[] ipPortPair = ipPort.split(":");
         nodes.add(new HostAndPort(ipPortPair[0].trim(), Integer.valueOf(ipPortPair[1].trim())));
      }

      JedisCluster jedisCluster = new JedisCluster(nodes, redisClusterCommandTimeout, 10000, 3, redisClusterPassword, poolConfig);
      this.jedisCluster = jedisCluster;
   }

   public JedisCluster getJedisCluster() {
      return this.jedisCluster;
   }
}
